TinyXml: TiXmlAttribute Class Reference

# TiXmlAttribute Class Reference

An attribute is a name-value pair. More...

`#include <tinyxml.h>`

Inheritance diagram for TiXmlAttribute:

List of all members.

## Public Member Functions
| TiXmlAttribute ()
| Construct an empty attribute.
| TiXmlAttribute (const std::string &_name, const std::string &_value)
| std::string constructor.
| TiXmlAttribute (const char *_name, const char *_value)
| Construct an attribute with a name and value.
const char * | Name () const
| Return the name of this attribute.
const char * | Value () const
| Return the value of this attribute.
const std::string & | ValueStr () const
| Return the value of this attribute.
int | IntValue () const
| Return the value of this attribute, converted to an integer.
double | DoubleValue () const
| Return the value of this attribute, converted to a double.
int | QueryIntValue (int *_value) const
| QueryIntValue examines the value string.
int | QueryDoubleValue (double *_value) const
| QueryDoubleValue examines the value string. See QueryIntValue().
void | SetName (const char *_name)
| Set the name of this attribute.
void | SetValue (const char *_value)
| Set the value.
void | SetIntValue (int _value)
| Set the value from an integer.
void | SetDoubleValue (double _value)
| Set the value from a double.
void | SetName (const std::string &_name)
| STL std::string form.
void | SetValue (const std::string &_value)
| STL std::string form.
const TiXmlAttribute * | Next () const
| Get the next sibling attribute in the DOM. Returns null at end.
const TiXmlAttribute * | Previous () const
| Get the previous sibling attribute in the DOM. Returns null at beginning.
virtual void | Print (FILE *cfile, int depth) const
| All TinyXml classes can print themselves to a filestream or the string class (TiXmlString in non-STL mode, std::string in STL mode.

## Detailed Description

An attribute is a name-value pair.

Elements have an arbitrary number of attributes, each with a unique name.

Note:
  The attributes are not TiXmlNodes, since they are not part of the tinyXML document object model. There are other suggested ways to look at this problem.

## Member Function Documentation

virtual void TiXmlAttribute::Print | ( | FILE * | cfile,
|  | int | depth |
| ) |  |  | const`[inline, virtual]`

All TinyXml classes can print themselves to a filestream or the string class (TiXmlString in non-STL mode, std::string in STL mode.

) Either or both cfile and str can be null.

This is a formatted print, and will insert tabs and newlines.

(For an unformatted stream, use the << operator.)

Implements TiXmlBase.

int TiXmlAttribute::QueryIntValue | ( | int * | _value | ) | const

QueryIntValue examines the value string.

It is an alternative to the IntValue() method with richer error checking. If the value is an integer, it is stored in 'value' and the call returns TIXML_SUCCESS. If it is not an integer, it returns TIXML_WRONG_TYPE.

A specialized but useful call. Note that for success it returns 0, which is the opposite of almost all other TinyXml calls.

The documentation for this class was generated from the following file:

- tinyxml.h